#### DRIVER FOR EPC
The purpose of this package is to instanciate epc devices in order to control 
them through can.
Giving the possibility to set different modes and read all the measurements.

Co-authors:
[Roberto Aldea](https://pypi.org/user/Raldea/), 
[Javier Sanz](https://pypi.org/user/javibu13/),
[Marius Crisan](https://pypi.org/user/mariuscrsn/)
